<a id="widgets.link_label.*"></a>

## \*

<a id="widgets.link_label.LinkLabel"></a>

## LinkLabel Objects

```python
class LinkLabel(QLabel)
```

<a id="widgets.link_label.LinkLabel.__init__"></a>

#### \_\_init\_\_

```python
def __init__(text='', link='', both=None, parent=None)
```

<a id="widgets.link_label.LinkLabel.setText"></a>

#### setText

```python
def setText(text)
```

<a id="widgets.link_label.LinkLabel.setLink"></a>

#### setLink

```python
def setLink(link)
```

<a id="widgets.link_label.LinkLabel._update_text"></a>

#### \_update\_text

```python
def _update_text()
```

